@@ -17,23 +17,24 @@ function(session, queryString){
  if(exists("rforcecom.debug") && rforcecom.debug){ message(t$value()) }
  # END DEBUG
  
+ x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
+ 
+ # Check whether it success or not
+ errorcode <- NA
+ errormessage <- NA
+ try(errorcode <- iconv(xmlValue(x.root[['Error']][['errorCode']]), from="UTF-8", to=""), TRUE)
+ try(errormessage <- iconv(xmlValue(x.root[['Error']][['message']]), from="UTF-8", to=""), TRUE)
+ if(!anyNA(errorcode,errormessage)){
+   stop(paste(errorcode, errormessage, sep=": "))
+ }
+ 
  # Parse XML
  xns <- getNodeSet(xmlParse(t$value()),'//SearchResults/SearchResult')
  xls <- sapply(xns, function(xn){ list(Id=xmlValue(xn), type=xmlGetAttr(xn, "type"), url=xmlGetAttr(xn, "url")) })
- xdf <- data.frame(t(xls))
- 
- # Parse XML
- if(t$value() != ""){
-  x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
-  
-  # Check whether it success or not
-  errorcode <- NA
-  errormessage <- NA
-  try(errorcode <- iconv(xmlValue(x.root[['Error']][['errorCode']]), from="UTF-8", to=""), TRUE)
-  try(errormessage <- iconv(xmlValue(x.root[['Error']][['message']]), from="UTF-8", to=""), TRUE)
-  if(!is.na(errorcode) && !is.na(errormessage)){
-   stop(paste(errorcode, errormessage, sep=": "))
-  }
+ if(length(xls)>0){
+   xdf <- data.frame(t(xls))
+ } else {
+   xdf <- NULL
  }
  
  return(xdf)
